@@ -10,7 +10,8 @@
 package MIDI::ALSA;
 no strict;
 use bytes;
-$VERSION = '1.13';
+$VERSION = '1.14';
+# 20111112 1.14 but output() does broadcast if destination is self
 # 20111108 1.13 repair version number
 # 20111108 1.12 output() does not broadcast if destination is set
 # 20111101 1.11 add parse_address(), and call automatically from connectto() etc
@@ -645,8 +646,8 @@ and the next event will be of type SND_SEQ_EVENT_PORT_UNSUBSCRIBED
 
 =item output($type,$flags,$tag,$queue,$time,\@source,\@destination,\@data)
 
-Send an ALSA-event-array from an output port.
-The format of the event is discussed in input() above.
+Send an ALSA-event from an output port.
+The format of the event is as discussed in input() above.
 The event will be output immediately
 either if no queue was created in the client
 or if the I<queue> parameter is set to SND_SEQ_QUEUE_DIRECT,
@@ -662,9 +663,13 @@ and the largest available will be used if I<$src_port> is greater than it.
 
 The I<@destination> is an array with two elements: ($dest_client, $dest_port),
 specifying the remote client/port to which the event will be sent.
-If I<$dest_client> is zero, then the event will be sent to all clients
-that are subscribed to the source_port (e.g. using I<connectto>()).
-Since version 1.12, if I<$dest_client> is non-zero,
+If I<$dest_client> is zero
+(as generated by I<scoreevent2alsa()> or I<noteevent()>),
+or is the same as the local client
+(as generated by I<input()>),
+then the event will be sent to all clients that the local port is connected to
+(see I<connectto>() and I<listconnectedto()>).
+But if you set I<dest_client> to a remote client,
 then the event will be sent to that
 I<dest_client:dest_port> and nowhere else.
 
@@ -894,7 +899,7 @@ allowing the interconnection of two other clients,
 a bit like I<aconnect 32 20>
 
 If an event is of type SND_SEQ_EVENT_PORT_UNSUBSCRIBED
-then the remote client and port seem to be zeroed-out,
+then the remote client and port are zeroed-out,
 which makes it hard to know which client has just disconnected.
 You have to consult listconnectedto() and listconnectedfrom()
 
